@@ -39,7 +39,11 @@ std::tuple<std::vector<int>, std::vector<std::pair<std::string,bool>>,
            std::vector<std::tuple<int,int,char,int> >,
            WellConnections>
 makeImportAndExportLists(const Dune::CpGrid& cpgrid,
+#if DUNE_VERSION_NEWER(DUNE_GRID, 2, 7)
+                         const Dune::Communication<MPI_Comm>& cc,
+#else
                          const Dune::CollectiveCommunication<MPI_Comm>& cc,
+#endif
                          const std::vector<Dune::cpgrid::OpmWellType> * wells,
                          const Dune::cpgrid::CombinedGridWellGraph* gridAndWells,
                          int root,
@@ -149,7 +153,11 @@ template<class Id>
 std::tuple<int, std::vector<Id> >
 scatterExportInformation(int numExport, const Id* exportGlobalGids,
                          const int* exportToPart, int root,
+#if DUNE_VERSION_NEWER(DUNE_GRID, 2, 7)
+                         const Communication<MPI_Comm>& cc)
+#else
                          const Dune::CollectiveCommunication<MPI_Comm>& cc)
+#endif
 {
     int numImport;
     std::vector<int> numberOfExportedVerticesPerProcess;
@@ -225,7 +233,11 @@ std::tuple<std::vector<int>, std::vector<std::pair<std::string,bool>>,
            std::vector<std::tuple<int,int,char,int> >,
            WellConnections>
 makeImportAndExportLists(const Dune::CpGrid&,
+#if DUNE_VERSION_NEWER(DUNE_GRID, 2, 7)
+                         const Communication<MPI_Comm>&,
+#else
                          const Dune::CollectiveCommunication<MPI_Comm>&,
+#endif
                          const std::vector<Dune::cpgrid::OpmWellType>*,
                          const Dune::cpgrid::CombinedGridWellGraph*,
                          int,
@@ -241,7 +253,11 @@ template
 std::tuple<int, std::vector<int> >
 scatterExportInformation(int numExport, const int*,
                          const int*, int,
+#if DUNE_VERSION_NEWER(DUNE_GRID, 2, 7)
+                         const Communication<MPI_Comm>&);
+#else
                          const Dune::CollectiveCommunication<MPI_Comm>&);
+#endif
 #endif // HAVE_MPI
 } // end namespace Dune
 } // end namespace cpgrid
@@ -276,11 +292,16 @@ std::tuple<std::vector<int>, std::vector<std::pair<std::string,bool>>,
 zoltanGraphPartitionGridOnRoot(const CpGrid& cpgrid,
                                const std::vector<OpmWellType> * wells,
                                const double* transmissibilities,
+#if DUNE_VERSION_NEWER(DUNE_GRID, 2, 7)
+                               const Communication<MPI_Comm>& cc,
+#else
                                const CollectiveCommunication<MPI_Comm>& cc,
+#endif
                                EdgeWeightMethod edgeWeightsMethod,
                                int root,
                                const double zoltanImbalanceTol,
-                               bool allowDistributedWells)
+                               bool allowDistributedWells,
+                               const std::map<std::string,std::string>& params)
 {
     int rc = ZOLTAN_OK - 1;
     float ver = 0;
@@ -298,6 +319,8 @@ zoltanGraphPartitionGridOnRoot(const CpGrid& cpgrid,
     }
     setDefaultZoltanParameters(zz);
     Zoltan_Set_Param(zz, "IMBALANCE_TOL", std::to_string(zoltanImbalanceTol).c_str());
+    for (const auto& [key, value] : params)
+        Zoltan_Set_Param(zz, key.c_str(), value.c_str());
 
     // For the load balancer one process has the whole grid and
     // all others an empty partition before loadbalancing.
@@ -360,15 +383,22 @@ zoltanGraphPartitionGridOnRoot(const CpGrid& cpgrid,
 class ZoltanSerialPartitioner
 {
 public:
+#if DUNE_VERSION_NEWER(DUNE_GRID, 2, 7)
+    using CommunicationType = Communication<MPI_Comm>;
+#else
+    using CommunicationType = CollectiveCommunication<MPI_Comm>;
+#endif
+
     ZoltanSerialPartitioner(const CpGrid& _cpgrid,
                             const std::vector<OpmWellType>* _wells,
                             const double* _transmissibilities,
-                            const CollectiveCommunication<MPI_Comm>& _cc,
+                            const CommunicationType& _cc,
                             EdgeWeightMethod _edgeWeightsMethod,
                             int _root,
                             const double _zoltanImbalanceTol,
                             bool _allowDistributedWells,
-                            int _numParts)
+                            int _numParts,
+                            const std::map<std::string,std::string>& param)
         : cpgrid(_cpgrid)
         , wells(_wells)
         , transmissibilities(_transmissibilities)
@@ -378,6 +408,7 @@ public:
         , zoltanImbalanceTol(_zoltanImbalanceTol)
         , allowDistributedWells(_allowDistributedWells)
         , numParts(_numParts)
+        , params(param)
     {
         if (wells) {
             const bool partitionIsEmpty = cc.rank() != root;
@@ -469,13 +500,16 @@ private:
         setDefaultZoltanParameters(zz);
         Zoltan_Set_Param(zz, "IMBALANCE_TOL", std::to_string(zoltanImbalanceTol).c_str());
         if (numParts > 0) {
-            Zoltan_Set_Param(zz, "NUM_GLOBAL_PARTS", std::to_string(numParts).c_str());
             Zoltan_Set_Param(zz, "NUM_GLOBAL_PARTS", std::to_string(numParts).c_str());
             Zoltan_Set_Param(zz, "RETURN_LISTS", "PARTS");
             Zoltan_Set_Param(zz, "DEBUG_LEVEL", "2");
         }
         else
             Zoltan_Set_Param(zz, "NUM_GLOBAL_PARTS", std::to_string(cc.size()).c_str());
+
+        for (const auto& [key, value] : params)
+            Zoltan_Set_Param(zz, key.c_str(), value.c_str());
+
         // For the load balancer one process has the whole grid and
         // all others an empty partition before loadbalancing.
         bool partitionIsEmpty = cc.rank() != root;
@@ -514,7 +548,7 @@ private:
     const CpGrid& cpgrid;
     const std::vector<OpmWellType>* wells;
     const double* transmissibilities;
-    const CollectiveCommunication<MPI_Comm>& cc;
+    const CommunicationType& cc;
     EdgeWeightMethod edgeWeightsMethod;
     int root;
     const double zoltanImbalanceTol;
@@ -536,6 +570,7 @@ private:
     std::vector<ZoltanId> importGlobalGidsVector;
     bool allowDistributedWells;
     int numParts;
+    const std::map<std::string,std::string>& params;
 };
 
 
@@ -547,14 +582,19 @@ std::tuple<std::vector<int>,
 zoltanSerialGraphPartitionGridOnRoot(const CpGrid& cpgrid,
                                      const std::vector<OpmWellType>* wells,
                                      const double* transmissibilities,
+#if DUNE_VERSION_NEWER(DUNE_GRID, 2, 7)
+                                     const Dune::Communication<MPI_Comm>& cc,
+#else
                                      const CollectiveCommunication<MPI_Comm>& cc,
+#endif
                                      EdgeWeightMethod edgeWeightsMethod,
                                      int root,
                                      const double zoltanImbalanceTol,
-                                     bool allowDistributedWells)
+                                     bool allowDistributedWells,
+                                     const std::map<std::string,std::string>& params)
 {
     ZoltanSerialPartitioner partitioner(cpgrid, wells, transmissibilities, cc, edgeWeightsMethod,
-                                        root, zoltanImbalanceTol, allowDistributedWells, 0);
+                                        root, zoltanImbalanceTol, allowDistributedWells, 0, params);
     return partitioner.partition();
 }
 
@@ -562,12 +602,16 @@ std::vector<int>
 zoltanGraphPartitionGridForJac(const CpGrid& cpgrid,
                                const std::vector<OpmWellType> * wells,
                                const double* transmissibilities,
+#if DUNE_VERSION_NEWER(DUNE_GRID, 2, 7)
+                               const Dune::Communication<MPI_Comm>& cc,
+#else
                                const CollectiveCommunication<MPI_Comm>& cc,
+#endif
                                EdgeWeightMethod edgeWeightsMethod, int root,
                                int numParts, const double zoltanImbalanceTol)
 {
     ZoltanSerialPartitioner partitioner(cpgrid, wells, transmissibilities, cc, edgeWeightsMethod,
-                                        root, zoltanImbalanceTol, false, numParts);
+                                        root, zoltanImbalanceTol, false, numParts, {});
     return partitioner.partitionForInfo();
 }
 
